@@ -180,7 +180,7 @@ OC.L10N.register(
     "Select tags and create new ones" : "Vybírejte štítky a vytvářejte nové",
     "Notes" : "Poznámky",
     "Notes for this bookmark …" : "Poznámky k této záložce…",
-    "Archived file" : "Zaarchivovaný soubor",
+    "Archived file" : "Archivovaný soubor",
     "Download file" : "Stáhnout si soubor",
     "Open file location" : "Otevřít umístění souboru",
     "Created {time} ago" : "Vytvořeno před {time}",
