@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Legosignaro",
     "No file provided for import" : "Neniu dosiero provizita por enporto",
-    "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
     "Select bookmark" : "Elekti legosignon",
     "Details" : "Detaloj",
     "Rename" : "Alinomi",
@@ -13,28 +12,24 @@ OC.L10N.register(
     "Move selection" : "Movi elekton",
     "Delete selection" : "Forigi elekton",
     "Select all" : "Elekti ĉion",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
     "Go back" : "Reveni",
     "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
     "New" : "Nova",
     "New folder" : "Nova dosierujo",
     "Search" : "Serĉi",
+    "Empty trash bin" : "Malpleni rubujon",
     "Enter a link" : "Entajpu ligilon",
     "Add a bookmark" : "Aldoni legosignon",
     "Enter folder title" : "Entajpu titolon de la dosierujo",
     "Rename folder" : "Alinomigi dosierujon",
     "Submit" : "Sendi",
     "Cancel" : "Nuligi",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
     "All bookmarks" : "Ĉiuj legosignoj",
     "Recent" : "Lastaj ŝanĝoj",
     "Shared with you" : "Kunhavata kun vi",
     "Files" : "Dosieroj",
     "Delete" : "Forigi",
     "Untagged" : "Sen etikedo",
-    "Settings" : "Agordoj",
     "No bookmarks here" : "Neniu legosigno ĉi tie",
     "Client apps" : "Klientaj aplikaĵoj",
     "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
