@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Bookmarks" : "Grāmatzīmes",
     "No file provided for import" : "Nav norādīta importējamā datne",
-    "Unsupported file type for import" : "Neatbalstīts datnes veids ievietošanai",
+    "Bookmark" : "Grāmatzīme",
     "Details" : "Detaļas",
     "Rename" : "Pārsaukt",
     "Copy link" : "Kopēt saiti",
@@ -13,16 +13,16 @@ OC.L10N.register(
     "New" : "Jauns",
     "New folder" : "Jauna mape",
     "Search" : "Meklēt",
+    "Empty trash bin" : "Izdzēst miskastes saturu",
     "Add a bookmark" : "Pievienot grāmatzīmi",
     "Rename folder" : "Pārsaukt mapi",
-    "Choose folder" : "Izvēlies mapi",
+    "Choose folder" : "Izvēlēties mapi",
     "Submit" : "Iesniegt",
     "Cancel" : "Atcelt",
     "Recent" : "Nesenās",
     "Shared with you" : "Koplietots ar jums",
     "Files" : "Datnes",
     "Delete" : "Dzēst",
-    "Settings" : "Iestatījumi",
     "Bookmarklet" : "Grāmatzīme",
     "Need help?" : "Vajadzīga palīdzība?",
     "Title" : "Amats",
