@@ -8,10 +8,10 @@ OC.L10N.register(
     "Select all" : "Hemmesini saýlaň",
     "New folder" : "Täze papka döretmek",
     "Search" : "Gözlemek",
+    "Empty trash bin" : "Boşadylan zibil",
     "Cancel" : "ýatyrmak",
     "Files" : "Faýllar",
     "Delete" : "Pozmak",
-    "Settings" : "Sazlamalar",
     "Link" : "Baglanyşyk",
     "Tags" : "Bellikler",
     "Sharing" : "Paýlaşmak",
