@@ -26,7 +26,8 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您共用的資料夾 \"%2$s\" ",
     "Someone unshared folder \"%s\" with you" : "某人已取消與你共用的資料夾 \"%s\"",
     "No file provided for import" : "無匯入檔案",
-    "Unsupported file type for import" : "匯入不支援的檔案格式",
+    "Failed to upload file" : "上傳檔案失敗",
+    "Unsupported file type for import: " : "匯入不支援的檔案格式：",
     "Bookmarks shared by %s" : "由 %s 共用的書籤",
     "Frequent bookmarks" : "常用書籤",
     "Recent bookmarks" : "最近使用的書籤",
@@ -73,18 +74,17 @@ OC.L10N.register(
     "Cancel selection" : "取消選擇",
     "Selected {folders} folders and {bookmarks} bookmarks" : "所選 {folders} 資料夾 和 {bookmarks} 書籤",
     "Do you really want to delete these items?" : "您確定要刪除這些項目嗎？",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選擇 %n 個書籤"],
-    "_Selected %n folder_::_Selected %n folders_" : ["已選擇 %n 個資料夾"],
     "Trash Bin" : "回收桶",
     "Go back" : "返回",
     "Share folder" : "分享資料夾",
+    "Open folder details" : "公開資料夾細節",
     "Select one or more tags" : "選擇一個或是多個標籤",
     "New" : "新增",
     "New bookmark" : "新增書籤",
     "New folder" : "新增資料夾",
     "Change to grid view" : "切換至網格檢視",
     "Change to list view" : "切換到列表視圖",
-    "Copy RSS Feed of current view" : "複製當前視圖的RSS Feed",
+    "Copy RSS Feed of current view" : "複製目前視圖的RSS Feed",
     "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed 需要使用您的 Nextcloud 身份驗證進行驗證",
     "Search" : "搜尋",
     "Empty trash bin" : "清空回收桶",
@@ -95,13 +95,10 @@ OC.L10N.register(
     "Sort by manual order" : "手動排序",
     "Sort by URL" : "依 URL 排序",
     "RSS feed copied" : "RSS feed 已複製",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["將 %n 書籤添加到新資料夾"],
     "Enter a link" : "輸入連結",
     "Enter a title" : "輸入標題",
     "No bookmarks found" : "未發現書籤",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾和 {bookmarks} 書籤",
-    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
-    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
     "Welcome to Bookmarks" : "歡迎來到 Bookmarks",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此應用程式允許您管理網絡上您最喜歡的地方的連結。將您的書籤分類到資料夾中，用標籤標記它們並與他人分享！該應用程式將定期檢查您所有連結的空閒時間並顯示不可用的連結。如果您在網絡上添加指向檔案的連結，該檔案將自動下載到您的 Nextcloud Files 中。您還可以導入從其他服務導出的書籤，或直接將所有瀏覽器中的書籤與此應用程式同步。",
     "Add a bookmark" : "新增書籤",
@@ -124,9 +121,7 @@ OC.L10N.register(
     "Importing bookmarks" : "匯入書籤",
     "Moving selection" : "移動選擇",
     "Adding selection to folders" : "將所選項目添加到資料夾",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
-    "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
+    "Emptying trashbin" : "清空回收桶",
     "All bookmarks" : "所有書籤",
     "Recent" : "最新",
     "Shared with you" : "與您分享",
@@ -138,7 +133,7 @@ OC.L10N.register(
     "Delete" : "刪除",
     "Untagged" : "未標記",
     "{used} bookmarks of {available} available" : "{available} 個可用書籤中的 {used} 個。",
-    "Settings" : "設定",
+    "Bookmarks Settings" : "書籤設定",
     "No bookmarked files" : "沒有已加書籤的檔案",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等檔案的書籤將自動保存到您的Nextcloud檔案中，因此即使連結脫機，您仍然可以找到它們。",
     "Nothing found" : "沒有找到任何內容",
@@ -157,6 +152,7 @@ OC.L10N.register(
     "The bookmarks app can automatically archive the web content of links you have bookmarked" : "書籤應用程式可以自動封存您加入書籤的網路內容",
     "Enable archiving" : "啟用封存",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入應該存儲書籤檔案的資料夾的路徑",
+    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "目前您的管理員已停用此應用程式的網絡存取，這就是目前停用自動存檔的原因。",
     "Auto-Backup" : "自動備份",
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
     "Enable backups" : "啟用備份",
