@@ -1,6 +1,7 @@
 <?php
+
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
@@ -14,14 +15,19 @@ use OCP\AppFramework\Db\Entity;
  *
  * @package OCA\Bookmarks\Db
  *
- * @method getFolderId()
+ * @method string getId()
+ * @method int getFolderId()
  * @method setFolderId(int $folderId)
- * @method getDescription
+ * @method string getDescription()
  * @method setDescription(string $description)
- * @method getCreatedAt
+ * @method int getCreatedAt()
  * @method setCreatedAt(int $createdAt)
  */
 class PublicFolder extends Entity {
+	/**
+	 * @var string
+	 */
+	public $id;
 	protected $folderId;
 	protected $description;
 	protected $createdAt;
