@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
@@ -131,7 +132,7 @@ class FileCache implements ICache {
 	 * @throws NotPermittedException
 	 */
 	public function remove($key) {
-		return (boolean) $this->getStorage()->getFile($key)->delete();
+		return (bool)$this->getStorage()->getFile($key)->delete();
 	}
 
 	/**
